####################################################
Keithley 2306 Dual Channel Battery/Charger Simulator
####################################################

.. autoclass:: pymeasure.instruments.keithley.Keithley2306
    :members:
    :show-inheritance:
    :inherited-members: CommonBase